<?php

if ( ! function_exists('offbeat_edge_event_options_map') ) {

	function offbeat_edge_event_options_map() {

		offbeat_edge_add_admin_page(array(
			'slug'  => '_event',
			'title' => esc_html__('Events','offbeat-core'),
			'icon'  => 'fa fa-calendar-o'
		));

        $panel_archive = offbeat_edge_add_admin_panel(
            array(
                'title' => esc_html__( 'Events Archive', 'offbeat-core' ),
                'name'  => 'panel_events_archive',
                'page'  => '_event'
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'name'        => 'event_archive_number_of_items',
                'type'        => 'text',
                'label'       => esc_html__( 'Number of Items', 'offbeat-core' ),
                'description' => esc_html__( 'Set number of items for your event list on archive pages. Default value is 12', 'offbeat-core' ),
                'parent'      => $panel_archive,
                'args'        => array(
                    'col_width' => 3
                )
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'name'          => 'event_archive_number_of_columns',
                'type'          => 'select',
                'label'         => esc_html__( 'Number of Columns', 'offbeat-core' ),
                'default_value' => '3',
                'description'   => esc_html__( 'Set number of columns for your event list on archive pages. Default value is 3 columns', 'offbeat-core' ),
                'parent'        => $panel_archive,
                'options'       => array(
                    '2' => esc_html__( '2 Columns', 'offbeat-core' ),
                    '3' => esc_html__( '3 Columns', 'offbeat-core' ),
                    '4' => esc_html__( '4 Columns', 'offbeat-core' ),
                    '5' => esc_html__( '5 Columns', 'offbeat-core' )
                )
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'name'          => 'event_archive_space_between_items',
                'type'          => 'select',
                'label'         => esc_html__( 'Space Between Items', 'offbeat-core' ),
                'description'   => esc_html__( 'Set space size between event items for your event list on archive pages. Default value is normal', 'offbeat-core' ),
                'default_value' => 'normal',
                'options'       => offbeat_edge_get_space_between_items_array(),
                'parent'        => $panel_archive
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'name'          => 'event_archive_image_size',
                'type'          => 'select',
                'label'         => esc_html__( 'Image Proportions', 'offbeat-core' ),
                'default_value' => 'original',
                'description'   => esc_html__( 'Set image proportions for your event list on archive pages. Default value is original', 'offbeat-core' ),
                'parent'        => $panel_archive,
                'options'       => array(
                    'full'      => esc_html__( 'Original', 'offbeat-core' ),
                    'landscape' => esc_html__( 'Landscape', 'offbeat-core' ),
                    'portrait'  => esc_html__( 'Portrait', 'offbeat-core' ),
                    'square'    => esc_html__( 'Square', 'offbeat-core' )
                )
            )
        );

		$panel = offbeat_edge_add_admin_panel(array(
			'title' => esc_html__('Event Single','offbeat-core'),
			'name'  => 'panel_event_single',
			'page'  => '_event'
		));

		offbeat_edge_add_admin_field(array(
			'name'          => 'event_single_show_categories',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Categories in Info','offbeat-core'),
			'description'   => esc_html__('Enabling this option will enable category meta description on Single Events.','offbeat-core'),
			'parent'        => $panel,
			'default_value' => 'yes'
		));

		offbeat_edge_add_admin_field(array(
			'name'          => 'event_single_show_location',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Location','offbeat-core'),
			'description'   => esc_html__('Enabling this option will enable location meta on Single Event.','offbeat-core'),
			'parent'        => $panel,
			'default_value' => 'yes'
		));

		offbeat_edge_add_admin_field(array(
			'name'          => 'event_single_date_showing',
			'type'          => 'select',
			'label'         => esc_html__('Date Showing','offbeat-core'),
			'description'   => esc_html__('Choose how will date info be shown on Single Event','offbeat-core'),
			'parent'        => $panel,
			'default_value' => 'start_duration',
			'options'		=> array(
				'start_duration' => esc_html__('Start Date and Duration','offbeat-core'),
				'start_end' => esc_html__('Start and End Date','offbeat-core'),
				'none' => esc_html__('None','offbeat-core'),
			)
		));

		offbeat_edge_add_admin_field(array(
			'name'          => 'event_single_reservation_showing',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Reservation Form','offbeat-core'),
			'description'   => esc_html__('Choose show/hide reservation form on Single Event','offbeat-core'),
			'parent'        => $panel,
			'default_value' => 'yes'
		));

        offbeat_edge_add_admin_field(array(
            'name'          => 'event_single_comments',
            'type'          => 'yesno',
            'label'         => esc_html__('Show Comments','offbeat-core'),
            'description'   => esc_html__('Enabling this option will show comments on your event.','offbeat-core'),
            'parent'        => $panel,
            'default_value' => 'no'
        ));

		offbeat_edge_add_admin_field(array(
			'name'          => 'event_single_show_pagination',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Pagination','offbeat-core'),
			'description'   => esc_html__('Enabling this option will turn on event pagination functionality.','offbeat-core'),
			'parent'        => $panel,
			'default_value' => 'no',
			'args' => array(
				'dependence' => true,
				'dependence_show_on_yes' => '#edgtff_navigate_same_category_container',
				'dependence_hide_on_yes' => ''
			)
		));

		$container_navigate_category = offbeat_edge_add_admin_container(array(
			'name'            => 'navigate_same_category_container',
			'parent'          => $panel,
			'hidden_property' => 'event_single_show_pagination',
			'hidden_value'    => 'no'
		));

		offbeat_edge_add_admin_field(array(
			'name'            => 'event_single_nav_same_category',
			'type'            => 'yesno',
			'label'           => esc_html__('Enable Pagination Through Same Category','offbeat-core'),
			'description'     => esc_html__('Enabling this option will make event pagination sort through current category.','offbeat-core'),
			'parent'          => $container_navigate_category,
			'default_value'   => 'no'
		));

		offbeat_edge_add_admin_field(array(
			'name'        => 'event_single_slug',
			'type'        => 'text',
			'label'       => esc_html__('Event Single Slug','offbeat-core'),
			'description' => esc_html__('Enter if you wish to use a different Single Project slug (Note: After entering slug, navigate to Settings -> Permalinks and click "Save" in order for changes to take effect)','offbeat-core'),
			'parent'      => $panel,
			'args'        => array(
				'col_width' => 3
			)
		));

	}

	add_action( 'offbeat_edge_action_options_map', 'offbeat_edge_event_options_map', 23);
}