<?php
namespace OffbeatCore\CPT\Events;

use OffbeatCore\Lib\PostTypeInterface;

/**
 * Class EventRegister
 * @package OffbeatCore\PostTypes\Event
 */
class EventsRegister implements PostTypeInterface {
    /**
     * @var string
     */
    private $base;

    public function __construct() {
        $this->base		= 'offbeat-event';
        $this->taxBase	= 'offbeat-event-category';

        add_filter( 'archive_template', array( $this, 'registerArchiveTemplate' ) );
        add_filter( 'single_template', array($this, 'registerSingleTemplate' ));
    }

    /**
     * @return string
     */
    public function getBase() {
        return $this->base;
    }

    /**
     * Registers custom post type with WordPress
     */
    public function register() {
        $this->registerPostType();
        $this->registerTax();
    }

    /**
     * Registers event archive template if one does'nt exists in theme.
     * Hooked to archive_template filter
     *
     * @param $archive string current template
     *
     * @return string string changed template
     */
    public function registerArchiveTemplate( $archive ) {
        global $post;

        if ( ! empty( $post ) && $post->post_type == $this->base ) {
            if ( ! file_exists( get_template_directory() . '/archive-' . $this->base . '.php' ) ) {
                return OFFBEAT_CORE_CPT_PATH . '/events/templates/archive-' . $this->base . '.php';
            }
        }

        return $archive;
    }

    /**
     * Registers event single template if one doesn't exists in theme.
     * Hooked to single_template filter
     * @param $single string current template
     * @return string string changed template
     */
    public function registerSingleTemplate($single) {
        global $post;

        if($post->post_type == $this->base) {
            if(!file_exists(get_template_directory().'/single-offbeat-event.php')) {
                return OFFBEAT_CORE_CPT_PATH.'/events/templates/single-'.$this->base.'.php';
            }
        }

        return $single;
    }

    /**
     * Registers custom post type with WordPress
     */
    private function registerPostType() {
        $menuPosition = 10;
        $menuIcon = 'dashicons-admin-post';
        $slug = 'event';

        if(offbeat_core_theme_installed()) {

	        if ( offbeat_edge_options()->getOptionValue( 'event_single_slug' ) ) {
		        $slug = offbeat_edge_options()->getOptionValue( 'event_single_slug' );
	        }
        }

        register_post_type( $this->base,
            array(
                'labels'		=> array(
                    'name'			=> esc_html__( 'Offbeat Events','offbeat-core' ),
                    'singular_name'	=> esc_html__( 'Offbeat Event','offbeat-core' ),
                    'add_item'		=> esc_html__( 'New Event','offbeat-core' ),
                    'add_new_item'	=> esc_html__( 'Add New Event','offbeat-core' ),
                    'edit_item'		=> esc_html__( 'Edit Event','offbeat-core' )
                ),
                'public'		=> true,
                'has_archive'	=> true,
                'rewrite'		=> array('slug' => $slug),
                'menu_position'	=> $menuPosition,
                'show_ui'		=> true,
                'supports'		=> array('author', 'title', 'editor', 'thumbnail', 'excerpt', 'page-attributes', 'comments'),
                'menu_icon'		=> $menuIcon
            )
        );
    }

    /**
     * Registers custom taxonomy with WordPress
     */
    private function registerTax() {
        $labels = array(
            'name'				=> esc_html__( 'Offbeat Event Categories', 'offbeat-core' ),
            'singular_name'		=> esc_html__( 'Event Category', 'offbeat-core' ),
            'search_items'		=> esc_html__( 'Search Event Categories', 'offbeat-core' ),
            'all_items'			=> esc_html__( 'All Event Categories', 'offbeat-core' ),
            'parent_item'		=> esc_html__( 'Parent Event Category', 'offbeat-core' ),
            'parent_item_colon'	=> esc_html__( 'Parent Event Category:', 'offbeat-core' ),
            'edit_item'			=> esc_html__( 'Edit Event Category', 'offbeat-core' ),
            'update_item'		=> esc_html__( 'Update Event Category', 'offbeat-core' ),
            'add_new_item'		=> esc_html__( 'Add New Event Category', 'offbeat-core' ),
            'new_item_name'		=> esc_html__( 'New Event Category Name', 'offbeat-core' ),
            'menu_name'			=> esc_html__( 'Offbeat Event Categories', 'offbeat-core' ),
        );

        register_taxonomy($this->taxBase, array($this->base), array(
            'hierarchical'		=> true,
            'labels'			=> $labels,
            'show_ui'			=> true,
            'query_var'			=> true,
	        'show_admin_column'	=> true,
            'rewrite'			=> array( 'slug' => 'event-category' ),
        ));
    }
}