<?php

if ( ! function_exists( 'offbeat_core_events_add_social_share_option' ) ) {
	function offbeat_core_events_add_social_share_option( $container ) {
		offbeat_edge_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'enable_social_share_on_offbeat-event',
				'default_value' => 'no',
				'label'         => esc_html__( 'Single Event', 'offbeat-core' ),
				'description'   => esc_html__( 'Show Social Share for Single Event', 'offbeat-core' ),
				'parent'        => $container
			)
		);
	}
	
	add_action( 'offbeat_edge_action_post_types_social_share', 'offbeat_core_events_add_social_share_option', 10, 1 );
}

if ( ! function_exists( 'offbeat_core_register_events' ) ) {
	function offbeat_core_register_events( $cpt_class_name ) {
		$cpt_class = array(
			'OffbeatCore\CPT\Events\EventsRegister'
		);
		
		$cpt_class_name = array_merge( $cpt_class_name, $cpt_class );
		
		return $cpt_class_name;
	}
	
	add_filter( 'offbeat_core_filter_register_custom_post_types', 'offbeat_core_register_events' );
}

if ( ! function_exists( 'offbeat_edge_events_meta_box_functions' ) ) {
	function offbeat_edge_events_meta_box_functions( $post_types ) {
		$post_types[] = 'offbeat-event';

		return $post_types;
	}
	
	add_filter( 'offbeat_edge_filter_meta_box_post_types_save', 'offbeat_edge_events_meta_box_functions' );
	add_filter( 'offbeat_edge_filter_meta_box_post_types_remove', 'offbeat_edge_events_meta_box_functions' );
	add_filter( 'offbeat_edge_filter_set_scope_for_meta_boxes', 'offbeat_edge_events_meta_box_functions' );
}

if ( ! function_exists( 'offbeat_core_set_breadcrumbs_output_for_events' ) ) {
	function offbeat_core_set_breadcrumbs_output_for_events( $childContent, $delimiter, $before, $after ) {

		if ( is_tax( 'offbeat-event-category' ) ) {
			$events_categories = wp_get_post_terms( get_the_ID(), 'offbeat-event-category' );
            $events_categories = $events_categories[0];
			$childContent       = '';

			if ( ! empty( $events_categories ) ) {
				if ( isset( $events_categories->parent ) && $events_categories->parent != 0 ) {
					$childContent .= get_category_parents( $events_categories->parent, true, ' ' . $delimiter );
				}
				$childContent .= $before . $events_categories->name . $after;
			}

		} elseif ( is_singular( 'offbeat-event' ) ) {
			$events_categories = wp_get_post_terms( offbeat_edge_get_page_id(), 'offbeat-event-category' );
			$childContent         = '';

			if ( ! empty( $events_categories ) && count( $events_categories ) ) {
				foreach ( $events_categories as $cat ) {
					$childContent .= '<a itemprop="url" href="' . get_term_link( $cat->term_id ) . '">' . $cat->name . '</a>' . $delimiter;
				}
			}

			$childContent .= $before . get_the_title() . $after;

		}

		return $childContent;
	}
	
	add_filter( 'offbeat_edge_filter_breadcrumbs_title_child_output', 'offbeat_core_set_breadcrumbs_output_for_events', 10, 4 );
}

if(!function_exists('offbeat_core_single_event')) {
	function offbeat_core_single_event() {
		$slug = offbeat_core_get_event_single_type();

		$params = array(
			'slug' => $slug
		);

		offbeat_core_get_cpt_single_module_template_part('templates/single/holder', 'events', '', $params);
	}
}

if(!function_exists('offbeat_core_get_event_single_type')) {
	function offbeat_core_get_event_single_type() {
		$slug = get_post_meta(get_the_ID(),'edgtf_event_layout_meta',true);
		return $slug;
	}
}

if(!function_exists('offbeat_core_get_single_event_images')) {
	function offbeat_core_get_single_event_images() {
		$image_ids       = get_post_meta(get_the_ID(), 'edgtf_event_images', true);

		return $image_ids;
	}
}

if(!function_exists('offbeat_core_event_get_info_part')) {
	function offbeat_core_event_get_info_part($part) {

		offbeat_core_get_cpt_single_module_template_part('templates/single/parts/'.$part, 'events');
	}
}

if (!function_exists('offbeat_core_event_get_categories')) {
	function offbeat_core_event_get_categories($id = ''){
		if ($id == ''){
			$id = get_the_ID();
		}
		$categories   = wp_get_post_terms($id, 'offbeat-event-category');
		$category_html = array();

		if(is_array($categories) && count($categories)){
			foreach($categories as $category) {
				$cat_html = '<a itemprop="url" class="edgtf-item-info-category" href="'.esc_url(get_term_link($category->term_id)).'">'.esc_html($category->name).'</a>';
				$category_html[] = $cat_html;
			}
		}
		$categories = implode(', ',$category_html);

		return $categories;
	}
}

if (!function_exists('offbeat_core_event_get_start_date')) {
	function offbeat_core_event_get_start_date($id = '',$default_format = true){
		if ($id == ''){
			$id = get_the_ID();
		}

		$start_date = '';

		$start_date_temp = strtotime(get_post_meta($id,'edgtf_event_start_date',true));

		if ($start_date_temp){
			if ($default_format){
				$start_date = date(get_option('date_format'),$start_date_temp);
			}
			else{
				$start_date['day'] = date('d',$start_date_temp);
				$start_date['month'] = date('M',$start_date_temp);
				$start_date['year'] = date('Y',$start_date_temp);
				$start_date['weekday'] = get_the_time('D');
			}
		}

		return $start_date;
	}
}


/*
** Function that returns start date, end date and duration for event
*/
if (!function_exists('offbeat_core_event_get_date_params')) {
	function offbeat_core_event_get_date_params($id = ''){
		if ($id == ''){
			$id = get_the_ID();
		}

		$date_params = array();
		$date_params['start_date'] = esc_html__('Unknown','offbeat-core');

		$start_date = strtotime(get_post_meta($id,'edgtf_event_start_date',true));
		$end_date = strtotime(get_post_meta($id,'edgtf_event_end_date',true));
		$duration = esc_html__('Unknown','offbeat-core');

		if ($start_date){
			$date_params['start_date'] = date(get_option('date_format'),$start_date);
		}

		if ($end_date){
			$date_params['end_date'] = date(get_option('date_format'), $end_date);
		}
		else{
			$end_date = $start_date;
			$date_params['end_date'] = $date_params['start_date'];
		}

		if($end_date && $start_date) {
			$duration_temp = $end_date - $start_date;
			$duration = $duration_temp / (60*60*24) + 1; //1 is for including end date
			$duration .= ($duration > 1) ? esc_html__(' Days','offbeat-core') : esc_html__(' Day','offbeat-core');
		}

		$date_params['duration'] = $duration;

		return $date_params;

	}
}

if (!function_exists('offbeat_core_event_get_date_part')) {
	function offbeat_core_event_get_date_part(){

		$date_showing = offbeat_edge_options()->getOptionValue('event_single_date_showing');

		if ($date_showing == 'none'){
			return false;
		}

		$date_params['date_showing'] = $date_showing;

		$date_params = array_merge($date_params,offbeat_core_event_get_date_params());

		return offbeat_core_get_cpt_single_module_template_part('templates/single/parts/date', 'events','',$date_params);

	}
}

if(!function_exists('offbeat_core_get_event_category_list')) {
	function offbeat_core_get_event_category_list($category = '') {
		$item_layout = 'full-width';

		$params = array(
			'type'      => $item_layout,
			'category'  => $category,
			'order_by'  => 'start-date',
			'show_more' => 'load-more'
		);

		$html = offbeat_edge_execute_shortcode('edgtf_event_list', $params);

		print $html;
	}
}

if ( ! function_exists( 'offbeat_core_get_events_single_related_posts' ) ) {
	/**
	 * Function for returning events single related posts
	 *
	 * @param $post_id
	 *
	 * @return WP_Query
	 */
	function offbeat_core_get_events_single_related_posts( $post_id ) {

		//Get categories
		$categories = wp_get_object_terms( $post_id, 'offbeat-event-category' );

		$category_ids = array();
		if ( $categories ) {
			foreach ( $categories as $category ) {
				$category_ids[] = $category->term_id;
			}
		}

		$hasRelatedByTag = false;

		if ( !empty( $categories ) ) {
			$related_by_category = offbeat_core_get_events_single_related_posts_by_param( $post_id, $category_ids, 'offbeat-event-category' );

			if ( ! empty( $related_by_category->posts ) ) {
				return $related_by_category;
			}
		}
	}
}

if ( ! function_exists( 'offbeat_core_get_events_single_related_posts_by_param' ) ) {
	/**
	 * @param $post_id - Post ID
	 * @param $term_ids - Category or Tag IDs
	 * @param $taxonomy
	 *
	 * @return WP_Query
	 */
	function offbeat_core_get_events_single_related_posts_by_param( $post_id, $term_ids, $taxonomy ) {
		$args = array(
			'post_status'    => 'publish',
			'post__not_in'   => array( $post_id ),
			'order'          => 'DESC',
			'orderby'        => 'date',
			'posts_per_page' => '4',
			'tax_query'      => array(
				array(
					'taxonomy' => $taxonomy,
					'field'    => 'term_id',
					'terms'    => $term_ids,
				),
			)
		);

		$related_by_taxonomy = new WP_Query( $args );

		return $related_by_taxonomy;
	}
}

if ( ! function_exists( 'offbeat_core_get_events_shortcodes_template_part' ) ) {
	/**
	 * Loads module template part.
	 *
	 * @param string $template name of the template to load
	 * @param string $shortcode name of the shortcode folder
	 * @param string $slug
	 * @param array $params array of parameters to pass to template
	 *
	 * @return string
	 */
	function offbeat_core_get_events_shortcodes_template_part( $template, $slug = '', $params = array() ) {

		//HTML Content from template
		$html          = '';
		$template_path = OFFBEAT_CORE_CPT_PATH . '/events/shortcodes/templates/';

		$temp = $template_path . '/' . $template;

		if ( is_array( $params ) && count( $params ) ) {
			extract( $params );
		}

		$template = '';

		if ( ! empty( $temp ) ) {
			if ( ! empty( $slug ) ) {
				$template = "{$temp}-{$slug}.php";

				if ( ! file_exists( $template ) ) {
					$template = $temp . '.php';
				}
			} else {
				$template = $temp . '.php';
			}
		}

		if ( $template ) {
			ob_start();
			include( $template );
			$html = ob_get_clean();
		}

		return $html;
	}
}

if ( ! function_exists( 'offbeat_core_get_archive_event_list' ) ) {
    function offbeat_core_get_archive_event_list( $edgtf_taxonomy_slug = '', $edgtf_taxonomy_name = '' ) {

        $number_of_items        = 12;
        $number_of_items_option = offbeat_edge_options()->getOptionValue( 'event_archive_number_of_items' );
        if ( ! empty( $number_of_items_option ) ) {
            $number_of_items = $number_of_items_option;
        }

        $number_of_columns        = 3;
        $number_of_columns_option = offbeat_edge_options()->getOptionValue( 'event_archive_number_of_columns' );
        if ( ! empty( $number_of_columns_option ) ) {
            $number_of_columns = $number_of_columns_option;
        }

        $space_between_items        = 'normal';
        $space_between_items_option = offbeat_edge_options()->getOptionValue( 'event_archive_space_between_items' );
        if ( ! empty( $space_between_items_option ) ) {
            $space_between_items = $space_between_items_option;
        }

        $image_size        = 'full';
        $image_size_option = offbeat_edge_options()->getOptionValue( 'event_archive_image_size' );
        if ( ! empty( $image_size_option ) ) {
            $image_size = $image_size_option;
        }

        $category = $edgtf_taxonomy_name === 'event-category' && ! empty( $edgtf_taxonomy_slug ) ? $edgtf_taxonomy_slug : '';

        $params = array(
            'type'                => 'thumbs',
            'number'              => $number_of_items,
            'number_of_columns'   => $number_of_columns,
            'space_between_items' => $space_between_items,
            'image_proportions'   => $image_size,
            'category'            => $category,
            'pagination_type'     => 'load-more'
        );

        $html = offbeat_edge_execute_shortcode( 'edgtf_event_list', $params );

        print $html;
    }
}