<?php
namespace OffbeatCore\CPT\Events\Shortcodes;

use OffbeatCore\Lib;

/**
 * Class EventInfo
 * @package OffbeatCore\CPT\Events\Shortcodes
 */
class EventInfo implements Lib\ShortcodeInterface {
	/**
	 * @var string
	 */
	private $base;

	public function __construct() {
		$this->base = 'edgtf_event_info';

		add_action('vc_before_init', array($this, 'vcMap'));
	}

	/**
	 * Returns base for shortcode
	 * @return string
	 */
	public function getBase() {
		return $this->base;
	}

	/**
	 * Maps shortcode to Visual Composer
	 *
	 * @see vc_map
	 */
	public function vcMap() {
		if(function_exists('vc_map')) {

			vc_map( array(
					'name' => esc_html__('Event Single Info','offbeat-core'),
					'base' => $this->getBase(),
					'category' => esc_html__('by OFFBEAT','offbeat-core'),
					'icon' => 'icon-wpb-event-single-info extended-custom-icon',
					'allowed_container_element' => 'vc_row',
					'params' => array(
						array(
							'type' => 'textfield',
							'heading' => esc_html__('Event ID','offbeat-core'),
							'param_name' => 'event_id',
							'admin_label' => true,
							'description' => esc_html__('If event ID not set, current page ID will be taken','offbeat-core')
						),
						array(
							'type' => 'textfield',
							'heading' => esc_html__('Title','offbeat-core'),
							'param_name' => 'title'
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__('Title Tag','offbeat-core'),
							'param_name' => 'title_tag',
							'value' => array(
								''   => '',
								'h2' => 'h2',
								'h3' => 'h3',
								'h4' => 'h4',
								'h5' => 'h5',
								'h6' => 'h6',
							),
							'dependency' => array('element' => 'title', 'not_empty' => true)
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__('Show Categories','offbeat-core'),
							'param_name' => 'show_categories',
							'value' => array(
								esc_html__('Yes','offbeat-core') => 'yes',
								esc_html__('No','offbeat-core') => 'no'
							)
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__('Show Location','offbeat-core'),
							'param_name' => 'show_location',
							'value' => array(
								esc_html__('Yes','offbeat-core') => 'yes',
								esc_html__('No','offbeat-core') => 'no'
							)
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__('Show Date','offbeat-core'),
							'param_name' => 'show_date',
							'value' => array(
								esc_html__('Show Start Date and Duration','offbeat-core') => 'date-duration',
								esc_html__('Show Start and End Date','offbeat-core') => 'start-end-date',
								esc_html__('No','offbeat-core') => 'no'
							)
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__('Show Aditional Info','offbeat-core'),
							'param_name' => 'show_additional',
							'value' => array(
								esc_html__('Yes','offbeat-core') => 'yes',
								esc_html__('No','offbeat-core') => 'no'
							)
						)
					)
				)
			);
		}
	}

	/**
	 * Renders shortcodes HTML
	 *
	 * @param $atts array of shortcode params
	 * @param $content string shortcode content
	 * @return string
	 */
	public function render($atts, $content = null) {

		$args = array(
			'event_id'        => '',
			'title'           => '',
			'title_tag'       => 'h5',
			'show_categories' => 'yes',
			'show_location'   => 'yes',
			'show_date'       => 'date-duration',
			'show_additional' => 'yes'
		);

		$params = shortcode_atts($args, $atts);

		if ($params['event_id'] == ''){
			$params['event_id'] = get_the_ID();
		}

		$params['date_params'] = $this->getDateParams($params);
		$params['custom_field_html'] = $this->getCustomFieldHtml($params);

		$html = offbeat_core_get_cpt_shortcode_module_template_part('events','event-info', '', $params);
		return $html;
	}


	/**
	 * Returns date parameters
	 *
	 * @param $params
	 *
	 * @return string
	 */
	private function getDateParams($params){
		$date_params = array();

		if (function_exists('offbeat_edge_event_get_date_params')){
			$date_params = offbeat_edge_event_get_date_params($params['event_id']);

			if ($params['show_date'] == 'date-duration'){
				$date_params['second_title'] = esc_html__('Duration:','offbeat-core');
				$date_params['second_desc'] = $date_params['duration'];
			}
			elseif ($params['show_date'] == 'start-end-date') {
				$date_params['second_title'] = esc_html__('End Date:','offbeat-core');
				$date_params['second_desc'] = $date_params['end_date'];
			}
		}

		return $date_params;
	}

	/**
	 * Generates custom fields html
	 *
	 * @param $params
	 *
	 * @return string
	 */
	public function getCustomFieldHtml($params){
		$html = '';


		
		return $html;
	}
}