<?php
namespace OffbeatCore\CPT\Events\Shortcodes;

use OffbeatCore\Lib;

/**
 * Class EventList
 * @package OffbeatCore\PostTypes\Event\Shortcodes
 */
class EventList implements Lib\ShortcodeInterface {
	/**
	 * @var string
	 */
	private $base;

	public function __construct() {
		$this->base = 'edgtf_event_list';

		add_action('vc_before_init', array($this, 'vcMap'));
	}

	/**
	 * Returns base for shortcode
	 * @return string
	 */
	public function getBase() {
		return $this->base;
	}

	/**
	 * Maps shortcode to Visual Composer
	 *
	 * @see vc_map
	 */
	public function vcMap() {
		if(function_exists('vc_map')) {

			vc_map( array(
					'name' => esc_html__('Offbeat Event List','offbeat-core'),
					'base' => $this->getBase(),
					'category' => esc_html__('by OFFBEAT','offbeat-core'),
					'icon' => 'icon-wpb-event-list extended-custom-icon',
					'allowed_container_element' => 'vc_row',
					'params' => array(
						array(
							'type'       => 'dropdown',
							'param_name' => 'type',
							'heading'    => esc_html__( 'List Type', 'offbeat-core' ),
							'value'      => array(
								esc_html__( 'Standard', 'offbeat-core' ) => 'standard',
								esc_html__( 'Simple', 'offbeat-core' )   => 'simple',
								esc_html__( 'Thumbs', 'offbeat-core' )   => 'thumbs',
							),
						),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'number_of_columns',
                            'heading'    => esc_html__( 'Number of Columns', 'offbeat-core' ),
                            'value'      => array(
                                esc_html__( 'None', 'offbeat-core' )  => '',
                                esc_html__( 'One', 'offbeat-core' )   => '1',
                                esc_html__( 'Two', 'offbeat-core' )   => '2',
                                esc_html__( 'Three', 'offbeat-core' ) => '3',
                                esc_html__( 'Four', 'offbeat-core' )  => '4',
                                esc_html__( 'Five', 'offbeat-core' )  => '5'
                            ),
                            'dependency' => Array( 'element' => 'type', 'value' => array( 'thumbs' ) ),
                        ),
                        array(
                            'type'        => 'dropdown',
                            'param_name'  => 'space_between_items',
                            'heading'     => esc_html__( 'Space Between Items', 'offbeat-core' ),
                            'value'       => array_flip( offbeat_edge_get_space_between_items_array() ),
                            'save_always' => true,
                            'dependency'  => array( 'element' => 'type', 'value' => array( 'thumbs' ) ),
                        ),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__('Skin','offbeat-core'),
							'param_name' => 'skin',
							'value' => array(
								esc_html__('Default','offbeat-core')  => '',
								esc_html__('Light','offbeat-core')    => 'edgtf-light-skin',
							),
						),
						array(
							'type' => 'textfield',
							'heading' => esc_html__('Padding Top/Bottom','offbeat-core'),
							'param_name' => 'padding_top_bottom',
							'description' => esc_html__('Enter top and bottom padding in px or %','offbeat-core'),

						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__('Title Tag','offbeat-core'),
							'param_name' => 'title_tag',
							'value' => array_flip( offbeat_edge_get_title_tag( true ) ),
//
						),
						array(
							'type' => 'textfield',
							'heading' => esc_html__('Title Size (px)','offbeat-core'),
							'param_name' => 'title_size',
							'description' => esc_html__('Default title size is 120px','offbeat-core'),
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__('Order By','offbeat-core'),
							'param_name' => 'order_by',
							'value' => array(
								esc_html__('Start Date','offbeat-core') => 'start-date',
								esc_html__('Date','offbeat-core') => 'date',
								esc_html__('Title','offbeat-core') => 'title',
								esc_html__('Menu Order','offbeat-core') => 'menu_order',
							),
							'group' => esc_html__('Query and Layout Options','offbeat-core')
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__('Order','offbeat-core'),
							'param_name' => 'order',
							'value' => array(
								esc_html__('ASC','offbeat-core') => 'ASC',
								esc_html__('DESC','offbeat-core') => 'DESC',
							),
							'group' => esc_html__('Query and Layout Options','offbeat-core')
						),
						array(
							'type' => 'textfield',
							'heading' => esc_html__('One-Category Event List','offbeat-core'),
							'param_name' => 'category',
							'description' => esc_html__('Enter one category slug (leave empty for showing all categories)','offbeat-core'),
							'group' => esc_html__('Query and Layout Options','offbeat-core')
						),
						array(
							'type' => 'textfield',
							'heading' => esc_html__('Number of Events Per Page','offbeat-core'),
							'param_name' => 'number',
							'value' => '-1',
							'description' => esc_html__('(enter -1 to show all)','offbeat-core'),
							'group' => esc_html__('Query and Layout Options','offbeat-core')
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__('Show Event by Status','offbeat-core'),
							'param_name' => 'event_status',
							'value' => array(
								esc_html__('All','offbeat-core') => 'all',
								esc_html__('Current and Upcoming','offbeat-core') => 'upcoming',
								esc_html__('Past','offbeat-core') => 'past',
							),
							'group' => esc_html__('Query and Layout Options','offbeat-core')
						),
						array(
							'type' => 'textfield',
							'heading' => esc_html__('Show Only Projects with Listed IDs','offbeat-core'),
							'param_name' => 'selected_projects',
							'description' => esc_html__('Delimit ID numbers by comma (leave empty for all)','offbeat-core'),
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'section_list_title',
							'heading'     => esc_html__( 'Section List Title', 'offbeat-core' ),
							'description' => esc_html__( 'Set event lists section title which appear as first item in list', 'offbeat-core' ),
							'dependency'  => array( 'element' => 'type', 'value' => array( 'thumbs' ) ),
						)
					)
				)
			);
		}
	}

	/**
	 * Renders shortcodes HTML
	 *
	 * @param $atts array of shortcode params
	 * @param $content string shortcode content
	 * @return string
	 */
	public function render($atts, $content = null) {
		$args = array(
			'type'                  => 'standard',
            'number_of_columns'     => 'none',
            'space_between_items'   => 'normal',
			'skin'                  => '',
			'padding_top_bottom'    => '',
			'title_tag'             => '',
			'title_size'            => '',
			'order_by'              => 'start-date',
			'order'                 => 'ASC',
			'event_status'          => 'all',
			'number'                => '-1',
			'category'              => '',
			'selected_projects'     => '',
			'next_page'             => '',
			'section_list_title'    => '',
			'image_proportions'     => 'full'
		);

		$params = shortcode_atts($args, $atts);
		extract($params);

		$query_array = $this->getQueryArray($params);
		$query_results = new \WP_Query($query_array);
		$params['query_results'] = $query_results;
		$params['default_date'] = false;

		$classes = $this->getEventClasses($params);

		$single_data = array();

		$single_data['item_style'] = $this->getItemStyle($params);
		$single_data['title_data'] = $this->getTitleData($params);
		$single_data['title_tag']  = $this->getTitleTag($params);
		$single_data['image_proportions'] = isset( $image_proportions ) && ! empty( $image_proportions ) ? $image_proportions : $args['image_proportions'];
		$single_data['skin'] = ! empty( $skin ) ? $skin : $args['skin'];

		$html = '';

		$html .= '<div class="offbeat-event-list-holder '.esc_attr($classes).'">';
		$html .= '<div class="offbeat-event-list-holder-inner">';

		if($query_results->have_posts()) {
			$i = 1;
			if ( $params['type'] === 'thumbs' && ! empty( $params['section_list_title'] ) ) {
				$html .= '<div class="edgtf-el-item edgtf-el-item-section"><div class="edgtf-el-item-wrap"><h3 class="edgtf-el-item-title">' . esc_attr($params['section_list_title']) .'</h3></div></div>';
			}
			while ( $query_results->have_posts() ) : $query_results->the_post();
				$params['id'] = get_the_ID();

				if (function_exists('offbeat_core_event_get_start_date')){
					$date = offbeat_core_event_get_start_date($params['id'],false);

					$single_data['date'] = $date;
				}

				$single_data  = array_merge( $single_data, $this->getSingleData( $params, $i ) );

				$html .= offbeat_core_get_events_shortcodes_template_part( 'list', $type, $single_data );

				$i ++;

			endwhile;
		} else {

			$html .= '<p>' . esc_html__( 'Sorry, no posts matched your criteria.', 'offbeat-core' ) . '</p>';

		}
		$html .= '</div>'; // close offbeat-event-list-holder-inner
		wp_reset_postdata();
		$html .= '</div>'; // close offbeat-event-list-holder
		return $html;
	}

	/**
	 * Generates event list query attribute array
	 *
	 * @param $params
	 *
	 * @return array
	 */
	public function getQueryArray($params){
		$tax_query = array();
		$meta_query = array();
		$order_by = $params['order_by'];

		if ($params['order_by'] == 'start-date'){
			$order_by = 'meta_value';
		}

		$query_array = array(
			'post_type'      => 'offbeat-event',
            'orderby'        => $order_by,
			'order'          => $params['order'],
			'posts_per_page' => $params['type'] === 'thumbs' && ! empty( $params['section_list_title'] ) ? intval($params['number'] - 1) :  $params['number']
		);

		if ($params['order_by'] === 'start-date'){
			$query_array['meta_key'] = 'edgtf_event_start_date'; //here because has to be added to query
		}

		//display date by event status, ex. end date larger then todays date or if it doesn't exist compare start date
		switch ($params['event_status']) {
			case 'upcoming':
				$meta_query = array(
					'relation' => 'OR',
					array(
						'key' => 'edgtf_event_end_date',
						'value' => date("Y-m-d"),
						'compare' => '>='
					),
					array(
						'relation' => 'AND',
						array(
							'key' => 'edgtf_event_end_date',
							'compare' => 'NOT EXISTS'
						),
						array(
							'key' => 'edgtf_event_start_date',
							'value' => date("Y-m-d"),
							'compare' => '>='
						),
					)
				);
				break;
			case 'past':
				$meta_query = array(
					'relation' => 'OR',
					array(
						'key' => 'edgtf_event_end_date',
						'value' => date("Y-m-d"),
						'compare' => '<'
					),
					array(
						'relation' => 'AND',
						array(
							'key' => 'edgtf_event_end_date',
							'compare' => 'NOT EXISTS'
						),
						array(
							'key' => 'edgtf_event_start_date',
							'value' => date("Y-m-d"),
							'compare' => '<'
						),
					)
				);
				break;
		}

		if (is_array($meta_query) && count($meta_query)){
			$query_array['meta_query'][] = $meta_query;
		}

		if(!empty($params['category'])){
			$tax_query['taxonomy'] = 'offbeat-event-category';
			$tax_query['field'] = 'slug';
			$tax_query['terms'] = $params['category'];
		}

		if (is_array($tax_query) && count($tax_query)){
			$query_array['tax_query'][] = $tax_query;
		}

		$project_ids = null;
		if (!empty($params['selected_projects'])) {
			$project_ids = explode(',', $params['selected_projects']);
			$query_array['post__in'] = $project_ids;
		}

		$paged = '';
		if(empty($params['next_page'])) {
			if(get_query_var('paged')) {
				$paged = get_query_var('paged');
			} elseif(get_query_var('page')) {
				$paged = get_query_var('page');
			}
		}

		if(!empty($params['next_page'])){
			$query_array['paged'] = $params['next_page'];

		} else {
			$query_array['paged'] = 1;
		}

		return $query_array;
	}

	/**
	 * Generates event classes
	 *
	 * @param $params
	 *
	 * @return string
	 */
	public function getEventClasses($params){
		$classes = array('offbeat-event-list-calendar', 'offbeat-event-list-full-width');

        if ( ! empty( $params['type'] ) ) {
            $classes = array(
                'offbeat-event-list-' . $params['type']
            );
        }
		
		if ( ! empty( $params['skin'] ) ) {
			$classes[] = $params['skin'];
		}
		
		if ( ! empty( $params['section_list_title'] ) ) {
			$classes[] = 'edgtf-el-has-title';
		}

        $classes[] = $this->getColumnNumberClass( $params['number_of_columns'] );
        $classes[] = ! empty( $params['space_between_items'] ) ? 'edgtf-' . $params['space_between_items'] . '-space' : 'edgtf-' . $params['space_between_items'] . '-space';

		return implode(' ',$classes);
	}

    public function getColumnNumberClass( $params ) {
        switch ( $params ) {
            case 1:
                $classes = 'edgtf-el-one-column';
                break;
            case 2:
                $classes = 'edgtf-el-two-columns';
                break;
            case 3:
                $classes = 'edgtf-el-three-columns';
                break;
            case 4:
                $classes = 'edgtf-el-four-columns';
                break;
            case 5:
                $classes = 'edgtf-el-five-columns';
                break;
            case 6:
                $classes = 'edgtf-el-no-columns';
                break;
            default:
                $classes = 'edgtf-el-no-columns';
                break;
        }

        return $classes;
    }

	/**
	 * Return item style
	 *
	 * @param $params
	 *
	 * @return string
	 */
	public function getItemStyle($params){
		$item_style = array();

		if (!empty($params['padding_top_bottom'])){
			$item_style[] = 'padding: '.$params['padding_top_bottom'].' 0';
		}

		return implode('; ', $item_style);
	}

	/**
	 * Return title tag
	 *
	 * @param $params
	 *
	 * @return string
	 */
	public function getTitleTag($params){
		$title_tag = 'h4';

		if (!empty($params['title_tag'])){ //!empty because of possible null value from load more
			$title_tag = $params['title_tag'];
		}

		return $title_tag;
	}

	/**
	 * Return title data
	 *
	 * @param $params
	 *
	 * @return string
	 */
	public function getTitleData($params){
		$title_data = array();

		if ($params['title_size'] !== ''){
			$title_data[] = 'data-font-size='.offbeat_edge_filter_px($params['title_size']).'';
		}
		else{
			$title_data[] = 'data-font-size=120';
		}

		return implode(' ', $title_data);
	}

	/**
	 * Generates single data array
	 *
	 * @param $params, $number
	 *
	 * @return array
	 */
	public function getSingleData($params,$number){
		$single_data = array();
		$even = false;
		$id = $params['id'];
		$default_date = $params['default_date'];
		$date = '';
		$categories = '';

		if ($number%2 == 0){
			$even = true;
		}

		if (function_exists('offbeat_core_event_get_start_date')){
			$date = offbeat_core_event_get_start_date($id,$default_date);
		}

		if (function_exists('offbeat_edge_event_get_categories')){
			$categories = offbeat_edge_event_get_categories($id);
		}

		$button_params = array();

		if ($even){
			$single_data['class'] = 'edgtf-el-item-even';
			$button_params['type'] = 'solid';
		} else{
			$single_data['class'] = 'edgtf-el-item-odd';
			$button_params['type'] = 'solid-white';
		}

		$button_params['link'] = get_permalink($id);
		$button_params['text'] = esc_html__('More Info','offbeat-core');

		$featured_image_array = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full'); //original size				
		$large_image = $featured_image_array[0];

		$location = get_post_meta($id,'edgtf_event_location',true);

		$single_data['date'] = ($date !== '') ? $date : '';
		$single_data['categories'] = ($categories !== '') ? $categories : '';
		$single_data['location'] = ($location !== '') ? $location : '';
		$single_data['button_params'] = $button_params;
		$single_data['image_background'] = ($large_image !== '') ? 'background-image: url('.esc_url($large_image).')' : '';

		return $single_data;
	}
}