<?php

if ( ! function_exists( 'offbeat_core_map_portfolio_meta' ) ) {
	function offbeat_core_map_portfolio_meta() {
		global $offbeat_edge_global_Framework;
		
		$offbeat_pages = array();
		$pages      = get_pages();
		foreach ( $pages as $page ) {
			$offbeat_pages[ $page->ID ] = $page->post_title;
		}
		
		//Portfolio Images
		
		$offbeat_portfolio_images = new OffbeatEdgeClassMetaBox( 'portfolio-item', esc_html__( 'Portfolio Images (multiple upload)', 'offbeat-core' ), '', '', 'portfolio_images' );
		$offbeat_edge_global_Framework->edgtMetaBoxes->addMetaBox( 'portfolio_images', $offbeat_portfolio_images );
		
		$offbeat_portfolio_image_gallery = new OffbeatEdgeClassMultipleImages( 'edgtf-portfolio-image-gallery', esc_html__( 'Portfolio Images', 'offbeat-core' ), esc_html__( 'Choose your portfolio images', 'offbeat-core' ) );
		$offbeat_portfolio_images->addChild( 'edgtf-portfolio-image-gallery', $offbeat_portfolio_image_gallery );
		
		//Portfolio Single Upload Images/Videos 
		
		$offbeat_portfolio_images_videos = offbeat_edge_add_meta_box(
			array(
				'scope' => array( 'portfolio-item' ),
				'title' => esc_html__( 'Portfolio Images/Videos (single upload)', 'offbeat-core' ),
				'name'  => 'edgtf_portfolio_images_videos'
			)
		);
		offbeat_edge_add_repeater_field(
			array(
				'name'        => 'edgtf_portfolio_single_upload',
				'parent'      => $offbeat_portfolio_images_videos,
				'button_text' => esc_html__( 'Add Image/Video', 'offbeat-core' ),
				'fields'      => array(
					array(
						'type'        => 'select',
						'name'        => 'file_type',
						'label'       => esc_html__( 'File Type', 'offbeat-core' ),
						'options' => array(
							'image' => esc_html__('Image','offbeat-core'),
							'video' => esc_html__('Video','offbeat-core'),
						)
					),
					array(
						'type'        => 'image',
						'name'        => 'single_image',
						'label'       => esc_html__( 'Image', 'offbeat-core' ),
						'dependency' => array(
							'show' => array(
								'file_type'  => 'image'
							)
						)
					),
					array(
						'type'        => 'select',
						'name'        => 'video_type',
						'label'       => esc_html__( 'Video Type', 'offbeat-core' ),
						'options'	  => array(
							'youtube' => esc_html__('YouTube', 'offbeat-core'),
							'vimeo' => esc_html__('Vimeo', 'offbeat-core'),
							'self' => esc_html__('Self Hosted', 'offbeat-core'),
						),
						'dependency' => array(
							'show' => array(
								'file_type'  => 'video'
							)
						)
					),
					array(
						'type'        => 'text',
						'name'        => 'video_id',
						'label'       => esc_html__( 'Video ID', 'offbeat-core' ),
						'dependency' => array(
							'show' => array(
								'file_type' => 'video',
								'video_type'  => array('youtube','vimeo')
							)
						)
					),
					array(
						'type'        => 'text',
						'name'        => 'video_mp4',
						'label'       => esc_html__( 'Video mp4', 'offbeat-core' ),
						'dependency' => array(
							'show' => array(
								'file_type' => 'video',
								'video_type'  => 'self'
							)
						)
					),
					array(
						'type'        => 'image',
						'name'        => 'video_cover_image',
						'label'       => esc_html__( 'Video Cover Image', 'offbeat-core' ),
						'dependency' => array(
							'show' => array(
								'file_type' => 'video',
								'video_type'  => 'self'
							)
						)
					)
				)
			)
		);
		
		//Portfolio Additional Sidebar Items
		
		$offbeat_additional_sidebar_items = offbeat_edge_add_meta_box(
			array(
				'scope' => array( 'portfolio-item' ),
				'title' => esc_html__( 'Additional Portfolio Sidebar Items', 'offbeat-core' ),
				'name'  => 'portfolio_properties'
			)
		);

		offbeat_edge_add_repeater_field(
			array(
				'name'        => 'edgtf_portfolio_properties',
				'parent'      => $offbeat_additional_sidebar_items,
				'button_text' => esc_html__( 'Add New Item', 'offbeat-core' ),
				'fields'      => array(
					array(
						'type'        => 'text',
						'name'        => 'item_title',
						'label'       => esc_html__( 'Item Title', 'offbeat-core' ),
					),
					array(
						'type'        => 'text',
						'name'        => 'item_text',
						'label'       => esc_html__( 'Item Text', 'offbeat-core' )
					),
					array(
						'type'        => 'text',
						'name'        => 'item_url',
						'label'       => esc_html__( 'Enter Full URL for Item Text Link', 'offbeat-core' )
					)
				)
			)
		);
	}
	
	add_action( 'offbeat_edge_action_meta_boxes_map', 'offbeat_core_map_portfolio_meta', 40 );
}