<?php
namespace OffbeatCore\CPT\Shortcodes\PricingList;

use OffbeatCore\Lib;

class PricingList implements Lib\ShortcodeInterface {
	private $base;
	
	function __construct() {
		$this->base = 'offbeat_pricing_list';
		add_action('vc_before_init', array($this, 'vcMap'));
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		vc_map(
			array(
				'name'                    => esc_html__( 'Pricing list', 'offbeat-core' ),
				'base'                    => $this->base,
				'as_parent'               => array( 'only' => 'offbeat_pricing_list_item' ),
				'content_element'         => true,
				'category'                => esc_html__( 'by OFFBEAT', 'offbeat-core' ),
				'icon'                    => 'icon-wpb-pricing-list extended-custom-icon',
				'show_settings_on_create' => true,
				'js_view'                 => 'VcColumnView',
				'params'                  => array(
					array(
						'type'        => 'dropdown',
						'param_name'  => 'skin',
						'heading'     => esc_html__('Skin', 'offbeat-core'),
						'value'       => array(
							esc_html__( 'Dark', 'offbeat-core' )   => '',
							esc_html__( 'Light', 'offbeat-core' )  => 'offbeat-pli-light'
						),
						'save_always' => true
					),
					array(
						'type'        => 'dropdown',
						'param_name'  => 'item_space',
						'heading'     => esc_html__('Space between items', 'offbeat-core'),
						'value'       => array(
							esc_html__( 'Normal', 'offbeat-core' ) => 'offbeat-pli-normal-space',
							esc_html__( 'Large', 'offbeat-core' )  => 'offbeat-pli-large-space'
						),
						'save_always' => true
					),
					array(
						'type'        => 'textfield',
						'param_name'  => 'button_text',
						'heading'     => esc_html__('Button Text', 'offbeat-core'),
					),
					array(
						'type'       => 'textfield',
						'param_name' => 'link',
						'heading'    => esc_html__('Button Link', 'offbeat-core'),
						'dependency' => array('element' => 'button_text', 'not_empty' => true)
					),
					array(
						'type'        => 'dropdown',
						'param_name'  => 'target',
						'heading'     => esc_html__('Link Target', 'offbeat-core'),
						'value'       => array_flip(offbeat_edge_get_link_target_array()),
						'dependency'  => array('element' => 'link', 'not_empty' => true)
					),
				)
			)
		);
	}

	public function render($atts, $content = null) {
		$args = array(
			'skin'        => '',
			'item_space'  => 'offbeat-pli-normal-space',
			'button_text' => '',
			'link'        => '',
			'target'      => '_self',
		);

		$params = shortcode_atts($args, $atts);

		$params['title_holder_styles'] = $this->getTitleHolderStyles($params);
		$params['holder_class']        = $this->getHolderClass($params);
		$params['content']             = $content;
		
		$html = offbeat_core_get_shortcode_module_template_part('templates/pricing-list', 'pricing-list', '', $params);

		return $html;
	}

	private function getTitleHolderStyles($params) {
		$styles = array();

		if(!empty($params['title_align'])) {
			$styles[] = 'text-align: '. $params['title_align'];
		}

		return implode( ';', $styles );
	}

	private function getHolderClass($params) {
		$class = array();

		if(!empty($params['skin'])) {
			$class[] = $params['skin'];
		}

		if(!empty($params['item_space'])) {
			$class[] = $params['item_space'];
		}

		return implode( ' ', $class );
	}
}