<?php

/*** Post Settings ***/

if ( ! function_exists( 'offbeat_edge_map_post_meta' ) ) {
	function offbeat_edge_map_post_meta() {
		
		$post_meta_box = offbeat_edge_add_meta_box(
			array(
				'scope' => array( 'post' ),
				'title' => esc_html__( 'Post', 'offbeat' ),
				'name'  => 'post-meta'
			)
		);
		
		offbeat_edge_add_meta_box_field(
			array(
				'name'          => 'edgtf_blog_single_sidebar_layout_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Sidebar Layout', 'offbeat' ),
				'description'   => esc_html__( 'Choose a sidebar layout for Blog single page', 'offbeat' ),
				'default_value' => '',
				'parent'        => $post_meta_box,
                'options'       => offbeat_edge_get_custom_sidebars_options( true )
			)
		);
		
		$offbeat_custom_sidebars = offbeat_edge_get_custom_sidebars();
		if ( count( $offbeat_custom_sidebars ) > 0 ) {
			offbeat_edge_add_meta_box_field( array(
				'name'        => 'edgtf_blog_single_custom_sidebar_area_meta',
				'type'        => 'selectblank',
				'label'       => esc_html__( 'Sidebar to Display', 'offbeat' ),
				'description' => esc_html__( 'Choose a sidebar to display on Blog single page. Default sidebar is "Sidebar"', 'offbeat' ),
				'parent'      => $post_meta_box,
				'options'     => offbeat_edge_get_custom_sidebars(),
				'args' => array(
					'select2' => true
				)
			) );
		}
		
		offbeat_edge_add_meta_box_field(
			array(
				'name'        => 'edgtf_blog_list_featured_image_meta',
				'type'        => 'image',
				'label'       => esc_html__( 'Blog List Image', 'offbeat' ),
				'description' => esc_html__( 'Choose an Image for displaying in blog list. If not uploaded, featured image will be shown.', 'offbeat' ),
				'parent'      => $post_meta_box
			)
		);
		
		offbeat_edge_add_meta_box_field(
			array(
				'name'          => 'edgtf_blog_masonry_gallery_fixed_dimensions_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Dimensions for Fixed Proportion', 'offbeat' ),
				'description'   => esc_html__( 'Choose image layout when it appears in Masonry lists in fixed proportion', 'offbeat' ),
				'default_value' => 'small',
				'parent'        => $post_meta_box,
				'options'       => array(
					'small'              => esc_html__( 'Small', 'offbeat' ),
					'large-width'        => esc_html__( 'Large Width', 'offbeat' ),
					'large-height'       => esc_html__( 'Large Height', 'offbeat' ),
					'large-width-height' => esc_html__( 'Large Width/Height', 'offbeat' )
				)
			)
		);
		
		offbeat_edge_add_meta_box_field(
			array(
				'name'          => 'edgtf_blog_masonry_gallery_original_dimensions_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Dimensions for Original Proportion', 'offbeat' ),
				'description'   => esc_html__( 'Choose image layout when it appears in Masonry lists in original proportion', 'offbeat' ),
				'default_value' => 'default',
				'parent'        => $post_meta_box,
				'options'       => array(
					'default'     => esc_html__( 'Default', 'offbeat' ),
					'large-width' => esc_html__( 'Large Width', 'offbeat' )
				)
			)
		);
		
		offbeat_edge_add_meta_box_field(
			array(
				'name'          => 'edgtf_show_title_area_blog_meta',
				'type'          => 'select',
				'default_value' => '',
				'label'         => esc_html__( 'Show Title Area', 'offbeat' ),
				'description'   => esc_html__( 'Enabling this option will show title area on your single post page', 'offbeat' ),
				'parent'        => $post_meta_box,
				'options'       => offbeat_edge_get_yes_no_select_array()
			)
		);

		do_action('offbeat_edge_action_blog_post_meta', $post_meta_box);
	}
	
	add_action( 'offbeat_edge_action_meta_boxes_map', 'offbeat_edge_map_post_meta', 20 );
}
