<?php

if ( ! function_exists( 'offbeat_edge_footer_options_map' ) ) {
	function offbeat_edge_footer_options_map() {

		offbeat_edge_add_admin_page(
			array(
				'slug'  => '_footer_page',
				'title' => esc_html__( 'Footer', 'offbeat' ),
				'icon'  => 'fa fa-sort-amount-asc'
			)
		);

		$footer_panel = offbeat_edge_add_admin_panel(
			array(
				'title' => esc_html__( 'Footer', 'offbeat' ),
				'name'  => 'footer',
				'page'  => '_footer_page'
			)
		);

		offbeat_edge_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'footer_in_grid',
				'default_value' => 'yes',
				'label'         => esc_html__( 'Footer in Grid', 'offbeat' ),
				'description'   => esc_html__( 'Enabling this option will place Footer content in grid', 'offbeat' ),
				'parent'        => $footer_panel
			)
		);

        offbeat_edge_add_admin_field(
            array(
                'type'          => 'yesno',
                'name'          => 'uncovering_footer',
                'default_value' => 'no',
                'label'         => esc_html__( 'Uncovering Footer', 'offbeat' ),
                'description'   => esc_html__( 'Enabling this option will make Footer gradually appear on scroll', 'offbeat' ),
                'parent'        => $footer_panel,
            )
        );

		offbeat_edge_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'show_footer_top',
				'default_value' => 'yes',
				'label'         => esc_html__( 'Show Footer Top', 'offbeat' ),
				'description'   => esc_html__( 'Enabling this option will show Footer Top area', 'offbeat' ),
				'parent'        => $footer_panel,
			)
		);
		
		$show_footer_top_container = offbeat_edge_add_admin_container(
			array(
				'name'       => 'show_footer_top_container',
				'parent'     => $footer_panel,
				'dependency' => array(
					'show' => array(
						'show_footer_top' => 'yes'
					)
				)
			)
		);

		offbeat_edge_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'footer_top_columns',
				'parent'        => $show_footer_top_container,
				'default_value' => '4',
				'label'         => esc_html__( 'Footer Top Columns', 'offbeat' ),
				'description'   => esc_html__( 'Choose number of columns for Footer Top area', 'offbeat' ),
				'options'       => array(
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4'
				)
			)
		);

		offbeat_edge_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'footer_top_columns_alignment',
				'default_value' => 'left',
				'label'         => esc_html__( 'Footer Top Columns Alignment', 'offbeat' ),
				'description'   => esc_html__( 'Text Alignment in Footer Columns', 'offbeat' ),
				'options'       => array(
					''       => esc_html__( 'Default', 'offbeat' ),
					'left'   => esc_html__( 'Left', 'offbeat' ),
					'center' => esc_html__( 'Center', 'offbeat' ),
					'right'  => esc_html__( 'Right', 'offbeat' )
				),
				'parent'        => $show_footer_top_container,
			)
		);

		offbeat_edge_add_admin_field(
			array(
				'name'        => 'footer_top_background_color',
				'type'        => 'color',
				'label'       => esc_html__( 'Background Color', 'offbeat' ),
				'description' => esc_html__( 'Set background color for top footer area', 'offbeat' ),
				'parent'      => $show_footer_top_container
			)
		);
		
		offbeat_edge_add_admin_field(
			array(
				'name'        => 'footer_top_background_image',
				'type'        => 'image',
				'label'       => esc_html__( 'Background Image', 'offbeat' ),
				'description' => esc_html__( 'Set background image for top footer area', 'offbeat' ),
				'parent'      => $show_footer_top_container
			)
		);

		offbeat_edge_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'show_footer_bottom',
				'default_value' => 'yes',
				'label'         => esc_html__( 'Show Footer Bottom', 'offbeat' ),
				'description'   => esc_html__( 'Enabling this option will show Footer Bottom area', 'offbeat' ),
				'parent'        => $footer_panel,
			)
		);

		$show_footer_bottom_container = offbeat_edge_add_admin_container(
			array(
				'name'            => 'show_footer_bottom_container',
				'parent'          => $footer_panel,
				'dependency' => array(
					'show' => array(
						'show_footer_bottom'  => 'yes'
					)
				)
			)
		);

		offbeat_edge_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'footer_bottom_columns',
				'default_value' => '2',
				'label'         => esc_html__( 'Footer Bottom Columns', 'offbeat' ),
				'description'   => esc_html__( 'Choose number of columns for Footer Bottom area', 'offbeat' ),
				'options'       => array(
					'1' => '1',
					'2' => '2',
					'3' => '3'
				),
				'parent'        => $show_footer_bottom_container,
			)
		);

		offbeat_edge_add_admin_field(
			array(
				'name'        => 'footer_bottom_background_color',
				'type'        => 'color',
				'label'       => esc_html__( 'Background Color', 'offbeat' ),
				'description' => esc_html__( 'Set background color for bottom footer area', 'offbeat' ),
				'parent'      => $show_footer_bottom_container
			)
		);
	}

	add_action( 'offbeat_edge_action_options_map', 'offbeat_edge_footer_options_map', 11 );
}