<?php

if ( ! function_exists( 'offbeat_edge_register_header_minimal_type' ) ) {
	/**
	 * This function is used to register header type class for header factory file
	 */
	function offbeat_edge_register_header_minimal_type( $header_types ) {
		$header_type = array(
			'header-minimal' => 'OffbeatEdgeNamespace\Modules\Header\Types\HeaderMinimal'
		);
		
		$header_types = array_merge( $header_types, $header_type );
		
		return $header_types;
	}
}

if ( ! function_exists( 'offbeat_edge_init_register_header_minimal_type' ) ) {
	/**
	 * This function is used to wait header-function.php file to init header object and then to init hook registration function above
	 */
	function offbeat_edge_init_register_header_minimal_type() {
		add_filter( 'offbeat_edge_filter_register_header_type_class', 'offbeat_edge_register_header_minimal_type' );
	}
	
	add_action( 'offbeat_edge_action_before_header_function_init', 'offbeat_edge_init_register_header_minimal_type' );
}

if ( ! function_exists( 'offbeat_edge_include_header_minimal_full_screen_menu' ) ) {
	/**
	 * Registers additional menu navigation for theme
	 */
	function offbeat_edge_include_header_minimal_full_screen_menu( $menus ) {
		$menus['popup-navigation'] = esc_html__( 'Full Screen Navigation', 'offbeat' );
		
		return $menus;
	}
	
	if ( offbeat_edge_check_is_header_type_enabled( 'header-minimal' ) ) {
		add_filter( 'offbeat_edge_filter_register_headers_menu', 'offbeat_edge_include_header_minimal_full_screen_menu' );
	}
}

if ( ! function_exists( 'offbeat_edge_get_fullscreen_menu_icon_class' ) ) {
	/**
	 * Loads full screen menu icon class
	 */
	function offbeat_edge_get_fullscreen_menu_icon_class() {

		$fullscreen_menu_icon_source = offbeat_edge_options()->getOptionValue( 'fullscreen_menu_icon_source' );

		$fullscreen_menu_icon_class_array = array(
			'edgtf-fullscreen-menu-opener'
		);

		$fullscreen_menu_icon_class_array[] = $fullscreen_menu_icon_source == 'icon_pack' ? 'edgtf-fullscreen-menu-opener-icon-pack' : 'edgtf-fullscreen-menu-opener-svg-path';

		return $fullscreen_menu_icon_class_array;
	}
}

if ( ! function_exists( 'offbeat_edge_get_fullscreen_menu_icon_html' ) ) {
	/**
	 * Loads fullscreen menu icon HTML
	 */
	function offbeat_edge_get_fullscreen_menu_icon_html() {

		$fullscreen_menu_icon_source	= offbeat_edge_options()->getOptionValue( 'fullscreen_menu_icon_source' );
		$fullscreen_menu_icon_pack		= offbeat_edge_options()->getOptionValue( 'fullscreen_menu_icon_pack' );
		$fullscreen_menu_icon_svg_path 	= offbeat_edge_options()->getOptionValue( 'fullscreen_menu_icon_svg_path' );

		$fullscreen_menu_icon_html = '';

		if ( ( $fullscreen_menu_icon_source == 'icon_pack' ) && ( isset( $fullscreen_menu_icon_pack ) ) ) {
			$fullscreen_menu_icon_html .= offbeat_edge_icon_collections()->getMenuIcon($fullscreen_menu_icon_pack);
		} else if ( isset( $fullscreen_menu_icon_svg_path ) ) {
			$fullscreen_menu_icon_html .= $fullscreen_menu_icon_svg_path; 
		}

		return $fullscreen_menu_icon_html;
	}
}

if ( ! function_exists( 'offbeat_edge_get_fullscreen_menu_close_icon_html' ) ) {
	/**
	 * Loads fullscreen menu close icon HTML
	 */
	function offbeat_edge_get_fullscreen_menu_close_icon_html() {

		$fullscreen_menu_icon_source			= offbeat_edge_options()->getOptionValue( 'fullscreen_menu_icon_source' );
		$fullscreen_menu_icon_pack				= offbeat_edge_options()->getOptionValue( 'fullscreen_menu_icon_pack' );
		$fullscreen_menu_close_icon_svg_path 	= offbeat_edge_options()->getOptionValue( 'fullscreen_menu_close_icon_svg_path' );

		$fullscreen_menu_close_icon_html = '';

		if ( ( $fullscreen_menu_icon_source == 'icon_pack' ) && ( isset( $fullscreen_menu_icon_pack ) ) ) {
			$fullscreen_menu_close_icon_html .= offbeat_edge_icon_collections()->getMenuCloseIcon($fullscreen_menu_icon_pack);
		} else if ( isset( $fullscreen_menu_close_icon_svg_path ) ) {
			$fullscreen_menu_close_icon_html .= $fullscreen_menu_close_icon_svg_path; 
		}

		return $fullscreen_menu_close_icon_html;
	}
}

if ( ! function_exists( 'offbeat_edge_register_header_minimal_full_screen_menu_widgets' ) ) {
	/**
	 * Registers additional widget areas for this header type
	 */
	function offbeat_edge_register_header_minimal_full_screen_menu_widgets() {
		
		register_sidebar(
			array(
				'id'            => 'fullscreen_menu_below',
				'name'          => esc_html__( 'Fullscreen Menu Widget Area', 'offbeat' ),
				'description'   => esc_html__( 'This widget area is rendered at the bottom of screen', 'offbeat' ),
				'before_widget' => '<div class="%2$s edgtf-fullscreen-menu-below-widget">',
				'after_widget'  => '</div>',
				'before_title'  => '<h5 class="edgtf-widget-title">',
				'after_title'   => '</h5>'
			)
		);
	}
	
	if ( offbeat_edge_check_is_header_type_enabled( 'header-minimal' ) ) {
		add_action( 'widgets_init', 'offbeat_edge_register_header_minimal_full_screen_menu_widgets' );
	}
}