<?php

if (!function_exists('offbeat_edge_sidearea_options_map')) {
    function offbeat_edge_sidearea_options_map() {

        offbeat_edge_add_admin_page(
            array(
                'slug'  => '_side_area_page',
                'title' => esc_html__('Side Area', 'offbeat'),
                'icon'  => 'fa fa-indent'
            )
        );

        $side_area_panel = offbeat_edge_add_admin_panel(
            array(
                'title' => esc_html__('Side Area', 'offbeat'),
                'name'  => 'side_area',
                'page'  => '_side_area_page'
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent'        => $side_area_panel,
                'type'          => 'select',
                'name'          => 'side_area_type',
                'default_value' => 'side-menu-slide-from-right',
                'label'         => esc_html__('Side Area Type', 'offbeat'),
                'description'   => esc_html__('Choose a type of Side Area', 'offbeat'),
                'options'       => array(
                    'side-menu-slide-from-right'       => esc_html__('Slide from Right Over Content', 'offbeat'),
                    'side-menu-slide-with-content'     => esc_html__('Slide from Right With Content', 'offbeat'),
                    'side-area-uncovered-from-content' => esc_html__('Side Area Uncovered from Content', 'offbeat'),
                ),
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent'        => $side_area_panel,
                'type'          => 'text',
                'name'          => 'side_area_width',
                'default_value' => '',
                'label'         => esc_html__('Side Area Width', 'offbeat'),
                'description'   => esc_html__('Enter a width for Side Area (px or %). Default width: 405px.', 'offbeat'),
                'args'          => array(
                    'col_width' => 3,
                )
            )
        );

        $side_area_width_container = offbeat_edge_add_admin_container(
            array(
                'parent'     => $side_area_panel,
                'name'       => 'side_area_width_container',
                'dependency' => array(
                    'show' => array(
                        'side_area_type' => 'side-menu-slide-from-right',
                    )
                )
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent'        => $side_area_width_container,
                'type'          => 'color',
                'name'          => 'side_area_content_overlay_color',
                'default_value' => '',
                'label'         => esc_html__('Content Overlay Background Color', 'offbeat'),
                'description'   => esc_html__('Choose a background color for a content overlay', 'offbeat'),
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent'        => $side_area_width_container,
                'type'          => 'text',
                'name'          => 'side_area_content_overlay_opacity',
                'default_value' => '',
                'label'         => esc_html__('Content Overlay Background Transparency', 'offbeat'),
                'description'   => esc_html__('Choose a transparency for the content overlay background color (0 = fully transparent, 1 = opaque)', 'offbeat'),
                'args'          => array(
                    'col_width' => 3
                )
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent'        => $side_area_panel,
                'type'          => 'select',
                'name'          => 'side_area_icon_source',
                'default_value' => 'icon_pack',
                'label'         => esc_html__('Select Side Area Icon Source', 'offbeat'),
                'description'   => esc_html__('Choose whether you would like to use icons from an icon pack or SVG icons', 'offbeat'),
                'options'       => offbeat_edge_get_icon_sources_array()
            )
        );

        $side_area_icon_pack_container = offbeat_edge_add_admin_container(
            array(
                'parent'     => $side_area_panel,
                'name'       => 'side_area_icon_pack_container',
                'dependency' => array(
                    'show' => array(
                        'side_area_icon_source' => 'icon_pack'
                    )
                )
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent'        => $side_area_icon_pack_container,
                'type'          => 'select',
                'name'          => 'side_area_icon_pack',
                'default_value' => 'font_elegant',
                'label'         => esc_html__('Side Area Icon Pack', 'offbeat'),
                'description'   => esc_html__('Choose icon pack for Side Area icon', 'offbeat'),
                'options'       => offbeat_edge_icon_collections()->getIconCollectionsExclude(array('linea_icons', 'dripicons', 'simple_line_icons'))
            )
        );

        $side_area_svg_icons_container = offbeat_edge_add_admin_container(
            array(
                'parent'     => $side_area_panel,
                'name'       => 'side_area_svg_icons_container',
                'dependency' => array(
                    'show' => array(
                        'side_area_icon_source' => 'svg_path'
                    )
                )
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent'      => $side_area_svg_icons_container,
                'type'        => 'textarea',
                'name'        => 'side_area_icon_svg_path',
                'label'       => esc_html__('Side Area Icon SVG Path', 'offbeat'),
                'description' => esc_html__('Enter your Side Area icon SVG path here. Please remove version and id attributes from your SVG path because of HTML validation', 'offbeat'),
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent'      => $side_area_svg_icons_container,
                'type'        => 'textarea',
                'name'        => 'side_area_close_icon_svg_path',
                'label'       => esc_html__('Side Area Close Icon SVG Path', 'offbeat'),
                'description' => esc_html__('Enter your Side Area close icon SVG path here. Please remove version and id attributes from your SVG path because of HTML validation', 'offbeat'),
            )
        );

        $side_area_icon_style_group = offbeat_edge_add_admin_group(
            array(
                'parent'      => $side_area_panel,
                'name'        => 'side_area_icon_style_group',
                'title'       => esc_html__('Side Area Icon Style', 'offbeat'),
                'description' => esc_html__('Define styles for Side Area icon', 'offbeat')
            )
        );

        $side_area_icon_style_row1 = offbeat_edge_add_admin_row(
            array(
                'parent' => $side_area_icon_style_group,
                'name'   => 'side_area_icon_style_row1'
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent' => $side_area_icon_style_row1,
                'type'   => 'colorsimple',
                'name'   => 'side_area_icon_color',
                'label'  => esc_html__('Color', 'offbeat')
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent' => $side_area_icon_style_row1,
                'type'   => 'colorsimple',
                'name'   => 'side_area_icon_hover_color',
                'label'  => esc_html__('Hover Color', 'offbeat')
            )
        );

        $side_area_icon_style_row2 = offbeat_edge_add_admin_row(
            array(
                'parent' => $side_area_icon_style_group,
                'name'   => 'side_area_icon_style_row2',
                'next'   => true
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent' => $side_area_icon_style_row2,
                'type'   => 'colorsimple',
                'name'   => 'side_area_close_icon_color',
                'label'  => esc_html__('Close Icon Color', 'offbeat')
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent' => $side_area_icon_style_row2,
                'type'   => 'colorsimple',
                'name'   => 'side_area_close_icon_hover_color',
                'label'  => esc_html__('Close Icon Hover Color', 'offbeat')
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent'      => $side_area_panel,
                'type'        => 'color',
                'name'        => 'side_area_background_color',
                'label'       => esc_html__('Background Color', 'offbeat'),
                'description' => esc_html__('Choose a background color for Side Area', 'offbeat')
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent'      => $side_area_panel,
                'type'        => 'text',
                'name'        => 'side_area_padding',
                'label'       => esc_html__('Padding', 'offbeat'),
                'description' => esc_html__('Define padding for Side Area in format top right bottom left', 'offbeat'),
                'args'        => array(
                    'col_width' => 3
                )
            )
        );

        offbeat_edge_add_admin_field(
            array(
                'parent'        => $side_area_panel,
                'type'          => 'selectblank',
                'name'          => 'side_area_aligment',
                'default_value' => '',
                'label'         => esc_html__('Text Alignment', 'offbeat'),
                'description'   => esc_html__('Choose text alignment for side area', 'offbeat'),
                'options'       => array(
                    ''       => esc_html__('Default', 'offbeat'),
                    'left'   => esc_html__('Left', 'offbeat'),
                    'center' => esc_html__('Center', 'offbeat'),
                    'right'  => esc_html__('Right', 'offbeat')
                )
            )
        );
    }

    add_action('offbeat_edge_action_options_map', 'offbeat_edge_sidearea_options_map', 15);
}