<?php
if (!function_exists('offbeat_edge_register_side_area_sidebar')) {
    /**
     * Register side area sidebar
     */
    function offbeat_edge_register_side_area_sidebar() {
        register_sidebar(
            array(
                'id'            => 'sidearea',
                'name'          => esc_html__('Side Area', 'offbeat'),
                'description'   => esc_html__('Side Area', 'offbeat'),
                'before_widget' => '<div id="%1$s" class="widget edgtf-sidearea %2$s">',
                'after_widget'  => '</div>',
                'before_title'  => '<h4 class="edgtf-widget-title">',
                'after_title'   => '</h4>'
            )
        );
    }

    add_action('widgets_init', 'offbeat_edge_register_side_area_sidebar');
}

if (!function_exists('offbeat_edge_side_menu_body_class')) {
    /**
     * Function that adds body classes for different side menu styles
     *
     * @param $classes array original array of body classes
     *
     * @return array modified array of classes
     */
    function offbeat_edge_side_menu_body_class($classes) {

        if (is_active_widget(false, false, 'edgtf_side_area_opener')) {

            if (offbeat_edge_options()->getOptionValue('side_area_type')) {

                $classes[] = 'edgtf-' . offbeat_edge_options()->getOptionValue('side_area_type');

            }

        }

        return $classes;
    }

    add_filter('body_class', 'offbeat_edge_side_menu_body_class');
}

if (!function_exists('offbeat_edge_get_side_area')) {
    /**
     * Loads side area HTML
     */
    function offbeat_edge_get_side_area() {

        if (is_active_widget(false, false, 'edgtf_side_area_opener')) {

            $parameters = array(
                'side_area_close_icon_class' => offbeat_edge_get_side_area_close_icon_class()
            );

            offbeat_edge_get_module_template_part('templates/sidearea', 'sidearea', '', $parameters);
        }
    }

    add_action('offbeat_edge_action_after_body_tag', 'offbeat_edge_get_side_area', 10);
}

if (!function_exists('offbeat_edge_get_side_area_close_class')) {
    /**
     * Loads side area close icon class
     */
    function offbeat_edge_get_side_area_close_icon_class() {

        $side_area_icon_source = offbeat_edge_options()->getOptionValue('side_area_icon_source');

        $side_area_close_icon_class_array = array(
            'edgtf-close-side-menu'
        );

        $side_area_close_icon_class_array[] = $side_area_icon_source == 'icon_pack' ? 'edgtf-close-side-menu-icon-pack' : 'edgtf-close-side-menu-svg-path';

        return $side_area_close_icon_class_array;
    }
}

if (!function_exists('offbeat_edge_get_side_area_close_icon_html')) {
    /**
     * Loads side area close icon HTML
     */
    function offbeat_edge_get_side_area_close_icon_html() {

        $side_area_icon_source = offbeat_edge_options()->getOptionValue('side_area_icon_source');
        $side_area_icon_pack = offbeat_edge_options()->getOptionValue('side_area_icon_pack');
        $side_area_close_icon_svg_path = offbeat_edge_options()->getOptionValue('side_area_close_icon_svg_path');

        $side_area_close_icon_html = '';

        if (($side_area_icon_source == 'icon_pack') && isset($side_area_icon_pack)) {
            $side_area_close_icon_html .= offbeat_edge_icon_collections()->getMenuCloseIcon($side_area_icon_pack);
        } else if (isset($side_area_close_icon_svg_path)) {
            $side_area_close_icon_html .= $side_area_close_icon_svg_path;
        }

        return $side_area_close_icon_html;
    }
}