<?php

/**
 * Force Visual Composer to initialize as "built into the theme". This will hide certain tabs under the Settings->Visual Composer page
 */
if ( function_exists( 'vc_set_as_theme' ) ) {
	vc_set_as_theme( true );
}

/**
 * Change path for overridden templates
 */
if ( function_exists( 'vc_set_shortcodes_templates_dir' ) ) {
	$dir = EDGE_ROOT_DIR . '/vc-templates';
	vc_set_shortcodes_templates_dir( $dir );
}

if ( ! function_exists( 'offbeat_edge_configure_visual_composer_frontend_editor' ) ) {
	/**
	 * Configuration for Visual Composer FrontEnd Editor
	 * Hooks on vc_after_init action
	 */
	function offbeat_edge_configure_visual_composer_frontend_editor() {
		/**
		 * Remove frontend editor
		 */
		if ( function_exists( 'vc_disable_frontend' ) ) {
			vc_disable_frontend();
		}
	}
	
	add_action( 'vc_after_init', 'offbeat_edge_configure_visual_composer_frontend_editor' );
}

if ( ! function_exists( 'offbeat_edge_vc_row_map' ) ) {
	/**
	 * Map VC Row shortcode
	 * Hooks on vc_after_init action
	 */
	function offbeat_edge_vc_row_map() {
		
		/******* VC Row shortcode - begin *******/
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'dropdown',
				'param_name' => 'row_content_width',
				'heading'    => esc_html__( 'Edge Row Content Width', 'offbeat' ),
				'value'      => array(
					esc_html__( 'Full Width', 'offbeat' ) => 'full-width',
					esc_html__( 'In Grid', 'offbeat' )    => 'grid'
				),
				'group'      => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'        => 'textfield',
				'param_name'  => 'anchor',
				'heading'     => esc_html__( 'Edge Anchor ID', 'offbeat' ),
				'description' => esc_html__( 'For example "home"', 'offbeat' ),
				'group'       => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'colorpicker',
				'param_name' => 'simple_background_color',
				'heading'    => esc_html__( 'Edge Background Color', 'offbeat' ),
				'group'      => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'attach_image',
				'param_name' => 'simple_background_image',
				'heading'    => esc_html__( 'Edge Background Image', 'offbeat' ),
				'group'      => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'        => 'dropdown',
				'param_name'  => 'disable_background_image',
				'heading'     => esc_html__( 'Edge Disable Background Image', 'offbeat' ),
				'value'       => array(
					esc_html__( 'Never', 'offbeat' )        => '',
					esc_html__( 'Below 1280px', 'offbeat' ) => '1280',
					esc_html__( 'Below 1024px', 'offbeat' ) => '1024',
					esc_html__( 'Below 768px', 'offbeat' )  => '768',
					esc_html__( 'Below 680px', 'offbeat' )  => '680',
					esc_html__( 'Below 480px', 'offbeat' )  => '480'
				),
				'save_always' => true,
				'description' => esc_html__( 'Choose on which stage you hide row background image', 'offbeat' ),
				'dependency'  => array( 'element' => 'simple_background_image', 'not_empty' => true ),
				'group'       => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'attach_image',
				'param_name' => 'parallax_background_image',
				'heading'    => esc_html__( 'Edge Parallax Background Image', 'offbeat' ),
				'group'      => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'        => 'textfield',
				'param_name'  => 'parallax_bg_speed',
				'heading'     => esc_html__( 'Edge Parallax Speed', 'offbeat' ),
				'description' => esc_html__( 'Set your parallax speed. Default value is 1.', 'offbeat' ),
				'dependency'  => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
				'group'       => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'textfield',
				'param_name' => 'parallax_bg_height',
				'heading'    => esc_html__( 'Edge Parallax Section Height (px)', 'offbeat' ),
				'dependency' => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
				'group'      => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'dropdown',
				'param_name' => 'content_text_aligment',
				'heading'    => esc_html__( 'Edge Content Aligment', 'offbeat' ),
				'value'      => array(
					esc_html__( 'Default', 'offbeat' ) => '',
					esc_html__( 'Left', 'offbeat' )    => 'left',
					esc_html__( 'Center', 'offbeat' )  => 'center',
					esc_html__( 'Right', 'offbeat' )   => 'right'
				),
				'group'      => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		/******* VC Row shortcode - end *******/
		
		/******* VC Row Inner shortcode - begin *******/
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'dropdown',
				'param_name' => 'row_content_width',
				'heading'    => esc_html__( 'Edge Row Content Width', 'offbeat' ),
				'value'      => array(
					esc_html__( 'Full Width', 'offbeat' ) => 'full-width',
					esc_html__( 'In Grid', 'offbeat' )    => 'grid'
				),
				'group'      => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'colorpicker',
				'param_name' => 'simple_background_color',
				'heading'    => esc_html__( 'Edge Background Color', 'offbeat' ),
				'group'      => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'attach_image',
				'param_name' => 'simple_background_image',
				'heading'    => esc_html__( 'Edge Background Image', 'offbeat' ),
				'group'      => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'        => 'dropdown',
				'param_name'  => 'disable_background_image',
				'heading'     => esc_html__( 'Edge Disable Background Image', 'offbeat' ),
				'value'       => array(
					esc_html__( 'Never', 'offbeat' )        => '',
					esc_html__( 'Below 1280px', 'offbeat' ) => '1280',
					esc_html__( 'Below 1024px', 'offbeat' ) => '1024',
					esc_html__( 'Below 768px', 'offbeat' )  => '768',
					esc_html__( 'Below 680px', 'offbeat' )  => '680',
					esc_html__( 'Below 480px', 'offbeat' )  => '480'
				),
				'save_always' => true,
				'description' => esc_html__( 'Choose on which stage you hide row background image', 'offbeat' ),
				'dependency'  => array( 'element' => 'simple_background_image', 'not_empty' => true ),
				'group'       => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'dropdown',
				'param_name' => 'content_text_aligment',
				'heading'    => esc_html__( 'Edge Content Aligment', 'offbeat' ),
				'value'      => array(
					esc_html__( 'Default', 'offbeat' ) => '',
					esc_html__( 'Left', 'offbeat' )    => 'left',
					esc_html__( 'Center', 'offbeat' )  => 'center',
					esc_html__( 'Right', 'offbeat' )   => 'right'
				),
				'group'      => esc_html__( 'Edge Settings', 'offbeat' )
			)
		);
		
		/******* VC Row Inner shortcode - end *******/
		
		/******* VC Revolution Slider shortcode - begin *******/
		
		if ( offbeat_edge_revolution_slider_installed() ) {
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'enable_paspartu',
					'heading'     => esc_html__( 'Edge Enable Passepartout', 'offbeat' ),
					'value'       => array_flip( offbeat_edge_get_yes_no_select_array( false ) ),
					'save_always' => true,
					'group'       => esc_html__( 'Edge Settings', 'offbeat' )
				)
			);
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'paspartu_size',
					'heading'     => esc_html__( 'Edge Passepartout Size', 'offbeat' ),
					'value'       => array(
						esc_html__( 'Tiny', 'offbeat' )   => 'tiny',
						esc_html__( 'Small', 'offbeat' )  => 'small',
						esc_html__( 'Normal', 'offbeat' ) => 'normal',
						esc_html__( 'Large', 'offbeat' )  => 'large'
					),
					'save_always' => true,
					'dependency'  => array( 'element' => 'enable_paspartu', 'value' => array( 'yes' ) ),
					'group'       => esc_html__( 'Edge Settings', 'offbeat' )
				)
			);
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'disable_side_paspartu',
					'heading'     => esc_html__( 'Edge Disable Side Passepartout', 'offbeat' ),
					'value'       => array_flip( offbeat_edge_get_yes_no_select_array( false ) ),
					'save_always' => true,
					'dependency'  => array( 'element' => 'enable_paspartu', 'value' => array( 'yes' ) ),
					'group'       => esc_html__( 'Edge Settings', 'offbeat' )
				)
			);
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'disable_top_paspartu',
					'heading'     => esc_html__( 'Edge Disable Top Passepartout', 'offbeat' ),
					'value'       => array_flip( offbeat_edge_get_yes_no_select_array( false ) ),
					'save_always' => true,
					'dependency'  => array( 'element' => 'enable_paspartu', 'value' => array( 'yes' ) ),
					'group'       => esc_html__( 'Edge Settings', 'offbeat' )
				)
			);
		}
		
		/******* VC Revolution Slider shortcode - end *******/
	}
	
	add_action( 'vc_after_init', 'offbeat_edge_vc_row_map' );
}