<?php

class OffbeatEdgeClassButtonWidget extends OffbeatEdgeClassWidget {
	public function __construct() {
		parent::__construct(
			'edgtf_button_widget',
			esc_html__( 'Offbeat Button Widget', 'offbeat' ),
			array( 'description' => esc_html__( 'Add button element to widget areas', 'offbeat' ) )
		);
		
		$this->setParams();
	}
	
	protected function setParams() {
		$this->params = array(
			array(
				'type'    => 'dropdown',
				'name'    => 'type',
				'title'   => esc_html__( 'Type', 'offbeat' ),
				'options' => array(
					'solid'   => esc_html__( 'Solid', 'offbeat' ),
					'outline' => esc_html__( 'Outline', 'offbeat' ),
					'simple'  => esc_html__( 'Simple', 'offbeat' )
				)
			),
			array(
				'type'        => 'dropdown',
				'name'        => 'size',
				'title'       => esc_html__( 'Size', 'offbeat' ),
				'options'     => array(
					'small'  => esc_html__( 'Small', 'offbeat' ),
					'medium' => esc_html__( 'Medium', 'offbeat' ),
					'large'  => esc_html__( 'Large', 'offbeat' ),
					'huge'   => esc_html__( 'Huge', 'offbeat' )
				),
				'description' => esc_html__( 'This option is only available for solid and outline button type', 'offbeat' )
			),
			array(
				'type'    => 'textfield',
				'name'    => 'text',
				'title'   => esc_html__( 'Text', 'offbeat' ),
				'default' => esc_html__( 'Button Text', 'offbeat' )
			),
			array(
				'type'  => 'textfield',
				'name'  => 'link',
				'title' => esc_html__( 'Link', 'offbeat' )
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'target',
				'title'   => esc_html__( 'Link Target', 'offbeat' ),
				'options' => offbeat_edge_get_link_target_array()
			),
			array(
				'type'  => 'colorpicker',
				'name'  => 'color',
				'title' => esc_html__( 'Color', 'offbeat' )
			),
			array(
				'type'  => 'colorpicker',
				'name'  => 'hover_color',
				'title' => esc_html__( 'Hover Color', 'offbeat' )
			),
			array(
				'type'        => 'colorpicker',
				'name'        => 'background_color',
				'title'       => esc_html__( 'Background Color', 'offbeat' ),
				'description' => esc_html__( 'This option is only available for solid button type', 'offbeat' )
			),
			array(
				'type'        => 'colorpicker',
				'name'        => 'hover_background_color',
				'title'       => esc_html__( 'Hover Background Color', 'offbeat' ),
				'description' => esc_html__( 'This option is only available for solid button type', 'offbeat' )
			),
			array(
				'type'        => 'colorpicker',
				'name'        => 'border_color',
				'title'       => esc_html__( 'Border Color', 'offbeat' ),
				'description' => esc_html__( 'This option is only available for solid and outline button type', 'offbeat' )
			),
			array(
				'type'        => 'colorpicker',
				'name'        => 'hover_border_color',
				'title'       => esc_html__( 'Hover Border Color', 'offbeat' ),
				'description' => esc_html__( 'This option is only available for solid and outline button type', 'offbeat' )
			),
			array(
				'type'        => 'textfield',
				'name'        => 'margin',
				'title'       => esc_html__( 'Margin', 'offbeat' ),
				'description' => esc_html__( 'Insert margin in format: top right bottom left (e.g. 10px 5px 10px 5px)', 'offbeat' )
			)
		);
	}
	
	public function widget( $args, $instance ) {
		$params = '';
		
		if ( ! is_array( $instance ) ) {
			$instance = array();
		}
		
		// Filter out all empty params
		$instance = array_filter( $instance, function ( $array_value ) {
			return trim( $array_value ) != '';
		} );
		
		// Default values
		if ( ! isset( $instance['text'] ) ) {
			$instance['text'] = 'Button Text';
		}
		
		// Generate shortcode params
		foreach ( $instance as $key => $value ) {
			$params .= " $key='$value' ";
		}
		
		echo '<div class="widget edgtf-button-widget">';
			echo do_shortcode( "[edgtf_button $params]" ); // XSS OK
		echo '</div>';
	}
}